@@ -4,12 +4,14 @@
 package client
 
 import (
+	"log/slog"
+	"os"
 	"os/user"
 	"path"
 	"regexp"
 	"strings"
 
-	"github.com/rs/zerolog/log"
+	"github.com/derailed/k9s/internal/slogs"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
@@ -50,14 +52,14 @@ func IsClusterScoped(ns string) bool {
 }
 
 // Namespaced converts a resource path to namespace and resource name.
-func Namespaced(p string) (string, string) {
-	ns, n := path.Split(p)
+func Namespaced(p string) (ns, name string) {
+	ns, name = path.Split(p)
 
-	return strings.Trim(ns, "/"), n
+	return strings.Trim(ns, "/"), name
 }
 
 // CoFQN returns a fully qualified container name.
-func CoFQN(m metav1.ObjectMeta, co string) string {
+func CoFQN(m *metav1.ObjectMeta, co string) string {
 	return MetaFQN(m) + ":" + co
 }
 
@@ -70,7 +72,7 @@ func FQN(ns, n string) string {
 }
 
 // MetaFQN returns a fully qualified resource name.
-func MetaFQN(m metav1.ObjectMeta) string {
+func MetaFQN(m *metav1.ObjectMeta) string {
 	if m.Namespace == "" {
 		return FQN(ClusterScope, m.Name)
 	}
@@ -81,12 +83,16 @@ func MetaFQN(m metav1.ObjectMeta) string {
 func mustHomeDir() string {
 	usr, err := user.Current()
 	if err != nil {
-		log.Fatal().Err(err).Msg("Die getting user home directory")
+		slog.Error("Die getting user home directory", slogs.Error, err)
+		os.Exit(1)
 	}
 	return usr.HomeDir
 }
 
 func toHostDir(host string) string {
-	h := strings.Replace(strings.Replace(host, "https://", "", 1), "http://", "", 1)
+	h := strings.Replace(
+		strings.Replace(host, "https://", "", 1),
+		"http://", "", 1,
+	)
 	return toFileName.ReplaceAllString(h, "_")
 }
