@@ -20,8 +20,6 @@ import (
 const (
 	mxCacheSize   = 100
 	mxCacheExpiry = 1 * time.Minute
-	podMXGVR      = "metrics.k8s.io/v1beta1/pods"
-	nodeMXGVR     = "metrics.k8s.io/v1beta1/nodes"
 )
 
 // MetricsDial tracks global metric server handle.
@@ -57,22 +55,22 @@ func NewMetricsServer(c Connection) *MetricsServer {
 }
 
 // ClusterLoad retrieves all cluster nodes metrics.
-func (m *MetricsServer) ClusterLoad(nos *v1.NodeList, nmx *mv1beta1.NodeMetricsList, mx *ClusterMetrics) error {
+func (*MetricsServer) ClusterLoad(nos *v1.NodeList, nmx *mv1beta1.NodeMetricsList, mx *ClusterMetrics) error {
 	if nos == nil || nmx == nil {
 		return fmt.Errorf("invalid node or node metrics lists")
 	}
 	nodeMetrics := make(NodesMetrics, len(nos.Items))
-	for _, no := range nos.Items {
-		nodeMetrics[no.Name] = NodeMetrics{
-			AllocatableCPU: no.Status.Allocatable.Cpu().MilliValue(),
-			AllocatableMEM: no.Status.Allocatable.Memory().Value(),
+	for i := range nos.Items {
+		nodeMetrics[nos.Items[i].Name] = NodeMetrics{
+			AllocatableCPU: nos.Items[i].Status.Allocatable.Cpu().MilliValue(),
+			AllocatableMEM: nos.Items[i].Status.Allocatable.Memory().Value(),
 		}
 	}
-	for _, mx := range nmx.Items {
-		if node, ok := nodeMetrics[mx.Name]; ok {
-			node.CurrentCPU = mx.Usage.Cpu().MilliValue()
-			node.CurrentMEM = mx.Usage.Memory().Value()
-			nodeMetrics[mx.Name] = node
+	for i := range nmx.Items {
+		if node, ok := nodeMetrics[nmx.Items[i].Name]; ok {
+			node.CurrentCPU = nmx.Items[i].Usage.Cpu().MilliValue()
+			node.CurrentMEM = nmx.Items[i].Usage.Memory().Value()
+			nodeMetrics[nmx.Items[i].Name] = node
 		}
 	}
 
@@ -88,7 +86,7 @@ func (m *MetricsServer) ClusterLoad(nos *v1.NodeList, nmx *mv1beta1.NodeMetricsL
 	return nil
 }
 
-func (m *MetricsServer) checkAccess(ns, gvr, msg string) error {
+func (m *MetricsServer) checkAccess(ns string, gvr *GVR, msg string) error {
 	if !m.HasMetrics() {
 		return errors.New("no metrics-server detected on cluster")
 	}
@@ -104,29 +102,31 @@ func (m *MetricsServer) checkAccess(ns, gvr, msg string) error {
 }
 
 // NodesMetrics retrieves metrics for a given set of nodes.
-func (m *MetricsServer) NodesMetrics(nodes *v1.NodeList, metrics *mv1beta1.NodeMetricsList, mmx NodesMetrics) {
+func (*MetricsServer) NodesMetrics(nodes *v1.NodeList, metrics *mv1beta1.NodeMetricsList, mmx NodesMetrics) {
 	if nodes == nil || metrics == nil {
 		return
 	}
 
-	for _, no := range nodes.Items {
-		mmx[no.Name] = NodeMetrics{
-			AllocatableCPU:       no.Status.Allocatable.Cpu().MilliValue(),
-			AllocatableMEM:       ToMB(no.Status.Allocatable.Memory().Value()),
-			AllocatableEphemeral: ToMB(no.Status.Allocatable.StorageEphemeral().Value()),
-			TotalCPU:             no.Status.Capacity.Cpu().MilliValue(),
-			TotalMEM:             ToMB(no.Status.Capacity.Memory().Value()),
-			TotalEphemeral:       ToMB(no.Status.Capacity.StorageEphemeral().Value()),
+	for i := range nodes.Items {
+		mmx[nodes.Items[i].Name] = NodeMetrics{
+			AllocatableCPU:       nodes.Items[i].Status.Allocatable.Cpu().MilliValue(),
+			AllocatableMEM:       ToMB(nodes.Items[i].Status.Allocatable.Memory().Value()),
+			AllocatableEphemeral: ToMB(nodes.Items[i].Status.Allocatable.StorageEphemeral().Value()),
+			TotalCPU:             nodes.Items[i].Status.Capacity.Cpu().MilliValue(),
+			TotalMEM:             ToMB(nodes.Items[i].Status.Capacity.Memory().Value()),
+			TotalEphemeral:       ToMB(nodes.Items[i].Status.Capacity.StorageEphemeral().Value()),
 		}
 	}
-	for _, c := range metrics.Items {
-		if mx, ok := mmx[c.Name]; ok {
-			mx.CurrentCPU = c.Usage.Cpu().MilliValue()
-			mx.CurrentMEM = ToMB(c.Usage.Memory().Value())
-			mx.AvailableCPU = mx.AllocatableCPU - mx.CurrentCPU
-			mx.AvailableMEM = mx.AllocatableMEM - mx.CurrentMEM
-			mmx[c.Name] = mx
+	for i := range metrics.Items {
+		mx, ok := mmx[metrics.Items[i].Name]
+		if !ok {
+			continue
 		}
+		mx.CurrentCPU = metrics.Items[i].Usage.Cpu().MilliValue()
+		mx.CurrentMEM = ToMB(metrics.Items[i].Usage.Memory().Value())
+		mx.AvailableCPU = mx.AllocatableCPU - mx.CurrentCPU
+		mx.AvailableMEM = mx.AllocatableMEM - mx.CurrentMEM
+		mmx[metrics.Items[i].Name] = mx
 	}
 }
 
@@ -151,7 +151,7 @@ func (m *MetricsServer) FetchNodesMetrics(ctx context.Context) (*mv1beta1.NodeMe
 	const msg = "user is not authorized to list node metrics"
 
 	mx := new(mv1beta1.NodeMetricsList)
-	if err := m.checkAccess(ClusterScope, nodeMXGVR, msg); err != nil {
+	if err := m.checkAccess(ClusterScope, NmxGVR, msg); err != nil {
 		return mx, err
 	}
 
@@ -182,7 +182,7 @@ func (m *MetricsServer) FetchNodeMetrics(ctx context.Context, n string) (*mv1bet
 	const msg = "user is not authorized to list node metrics"
 
 	mx := new(mv1beta1.NodeMetrics)
-	if err := m.checkAccess(ClusterScope, nodeMXGVR, msg); err != nil {
+	if err := m.checkAccess(ClusterScope, NmxGVR, msg); err != nil {
 		return mx, err
 	}
 
@@ -222,7 +222,7 @@ func (m *MetricsServer) FetchPodsMetrics(ctx context.Context, ns string) (*mv1be
 	if ns == NamespaceAll {
 		ns = BlankNamespace
 	}
-	if err := m.checkAccess(ns, podMXGVR, msg); err != nil {
+	if err := m.checkAccess(ns, PmxGVR, msg); err != nil {
 		return mx, err
 	}
 
@@ -273,7 +273,7 @@ func (m *MetricsServer) FetchPodMetrics(ctx context.Context, fqn string) (*mv1be
 	if ns == NamespaceAll {
 		ns = BlankNamespace
 	}
-	if err := m.checkAccess(ns, podMXGVR, msg); err != nil {
+	if err := m.checkAccess(ns, PmxGVR, msg); err != nil {
 		return mx, err
 	}
 
@@ -290,19 +290,19 @@ func (m *MetricsServer) FetchPodMetrics(ctx context.Context, fqn string) (*mv1be
 }
 
 // PodsMetrics retrieves metrics for all pods in a given namespace.
-func (m *MetricsServer) PodsMetrics(pods *mv1beta1.PodMetricsList, mmx PodsMetrics) {
+func (*MetricsServer) PodsMetrics(pods *mv1beta1.PodMetricsList, mmx PodsMetrics) {
 	if pods == nil {
 		return
 	}
 
 	// Compute all pod's containers metrics.
-	for _, p := range pods.Items {
+	for i := range pods.Items {
 		var mx PodMetrics
-		for _, c := range p.Containers {
+		for _, c := range pods.Items[i].Containers {
 			mx.CurrentCPU += c.Usage.Cpu().MilliValue()
 			mx.CurrentMEM += ToMB(c.Usage.Memory().Value())
 		}
-		mmx[p.Namespace+"/"+p.Name] = mx
+		mmx[pods.Items[i].Namespace+"/"+pods.Items[i].Name] = mx
 	}
 }
 
