@@ -5,22 +5,25 @@ package config
 
 import (
 	"errors"
+	"fmt"
 	"io/fs"
 	"log/slog"
 	"os"
 	"sync"
 
+	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/config/data"
 	"github.com/derailed/k9s/internal/config/json"
 	"github.com/derailed/k9s/internal/slogs"
-	"gopkg.in/yaml.v2"
+	"gopkg.in/yaml.v3"
+	"k8s.io/apimachinery/pkg/util/sets"
 )
 
 // Alias tracks shortname to GVR mappings.
-type Alias map[string]string
+type Alias map[string]*client.GVR
 
 // ShortNames represents a collection of shortnames for aliases.
-type ShortNames map[string][]string
+type ShortNames map[*client.GVR][]string
 
 // Aliases represents a collection of aliases.
 type Aliases struct {
@@ -35,29 +38,17 @@ func NewAliases() *Aliases {
 	}
 }
 
-func (a *Aliases) AliasesFor(s string) []string {
-	aa := make([]string, 0, 10)
-
+func (a *Aliases) AliasesFor(gvr *client.GVR) sets.Set[string] {
 	a.mx.RLock()
 	defer a.mx.RUnlock()
-	for k, v := range a.Alias {
-		if v == s {
-			aa = append(aa, k)
+
+	ss := sets.New[string]()
+	for alias, aliasGVR := range a.Alias {
+		if aliasGVR == gvr {
+			ss.Insert(alias)
 		}
 	}
 
-	return aa
-}
-
-// Keys returns all aliases keys.
-func (a *Aliases) Keys() []string {
-	a.mx.RLock()
-	defer a.mx.RUnlock()
-
-	ss := make([]string, 0, len(a.Alias))
-	for k := range a.Alias {
-		ss = append(ss, k)
-	}
 	return ss
 }
 
@@ -89,24 +80,27 @@ func (a *Aliases) Clear() {
 }
 
 // Get retrieves an alias.
-func (a *Aliases) Get(k string) (string, bool) {
+func (a *Aliases) Get(alias string) (*client.GVR, bool) {
 	a.mx.RLock()
 	defer a.mx.RUnlock()
 
-	v, ok := a.Alias[k]
-	return v, ok
+	gvr, ok := a.Alias[alias]
+	if ok && !gvr.IsK8sRes() {
+		if rgvr, found := a.Alias[gvr.String()]; found {
+			return rgvr, found
+		}
+	}
+
+	return gvr, ok
 }
 
 // Define declares a new alias.
-func (a *Aliases) Define(gvr string, aliases ...string) {
+func (a *Aliases) Define(gvr *client.GVR, aliases ...string) {
+	if gvr.String() == "deployment" {
+		fmt.Println("!!YO!!")
+	}
 	a.mx.Lock()
 	defer a.mx.Unlock()
-
-	// BOZO!! Could not get full events struct using this api group??
-	if gvr == "events.k8s.io/v1/events" || gvr == "extensions/v1beta1" {
-		return
-	}
-
 	for _, alias := range aliases {
 		if _, ok := a.Alias[alias]; !ok && alias != "" {
 			a.Alias[alias] = gvr
@@ -117,12 +111,10 @@ func (a *Aliases) Define(gvr string, aliases ...string) {
 // Load K9s aliases.
 func (a *Aliases) Load(path string) error {
 	a.loadDefaultAliases()
-
 	f, err := EnsureAliasesCfgFile()
 	if err != nil {
 		slog.Error("Unable to gen config aliases", slogs.Error, err)
 	}
-
 	// load global alias file
 	if err := a.LoadFile(f); err != nil {
 		return err
@@ -132,11 +124,18 @@ func (a *Aliases) Load(path string) error {
 	return a.LoadFile(path)
 }
 
+type aliases struct {
+	Alias map[string]string `yaml:"aliases"`
+}
+
+func newAliases(s int) aliases {
+	return aliases{
+		Alias: make(map[string]string, s),
+	}
+}
+
 // LoadFile loads alias from a given file.
 func (a *Aliases) LoadFile(path string) error {
-	if path == "" {
-		return nil
-	}
 	if _, err := os.Stat(path); errors.Is(err, fs.ErrNotExist) {
 		return nil
 	}
@@ -149,23 +148,23 @@ func (a *Aliases) LoadFile(path string) error {
 		slog.Warn("Aliases validation failed", slogs.Error, err)
 	}
 
-	var aa Aliases
+	var aa aliases
 	if err := yaml.Unmarshal(bb, &aa); err != nil {
 		return err
 	}
 	a.mx.Lock()
 	defer a.mx.Unlock()
-	for k, v := range aa.Alias {
-		a.Alias[k] = v
+	for alias, cmd := range aa.Alias {
+		a.Alias[alias] = client.NewGVR(cmd)
 	}
 
 	return nil
 }
 
-func (a *Aliases) declare(key string, aliases ...string) {
-	a.Alias[key] = key
+func (a *Aliases) declare(gvr *client.GVR, aliases ...string) {
+	a.Alias[gvr.String()] = gvr
 	for _, alias := range aliases {
-		a.Alias[alias] = key
+		a.Alias[alias] = gvr
 	}
 }
 
@@ -173,22 +172,20 @@ func (a *Aliases) loadDefaultAliases() {
 	a.mx.Lock()
 	defer a.mx.Unlock()
 
-	a.declare("help", "h", "?")
-	a.declare("quit", "q", "q!", "qa", "Q")
-	a.declare("aliases", "alias", "a")
-	// !!BOZO!!
-	// a.declare("popeye", "pop")
-	a.declare("helm", "charts", "chart", "hm")
-	a.declare("dir", "d")
-	a.declare("contexts", "context", "ctx")
-	a.declare("users", "user", "usr")
-	a.declare("groups", "group", "grp")
-	a.declare("portforwards", "portforward", "pf")
-	a.declare("benchmarks", "benchmark", "bench")
-	a.declare("screendumps", "screendump", "sd")
-	a.declare("pulses", "pulse", "pu", "hz")
-	a.declare("xrays", "xray", "x")
-	a.declare("workloads", "workload", "wk")
+	a.declare(client.HlpGVR, "h", "?")
+	a.declare(client.QGVR, "q", "q!", "qa", "Q")
+	a.declare(client.AliGVR, "alias", "a")
+	a.declare(client.HmGVR, "charts", "chart", "hm")
+	a.declare(client.DirGVR, "dir", "d")
+	a.declare(client.CtGVR, "context", "ctx")
+	a.declare(client.UsrGVR, "user", "usr")
+	a.declare(client.GrpGVR, "group", "grp")
+	a.declare(client.PfGVR, "portforward", "pf")
+	a.declare(client.BeGVR, "benchmark", "bench")
+	a.declare(client.SdGVR, "screendump", "sd")
+	a.declare(client.PuGVR, "pulse", "pu", "hz")
+	a.declare(client.XGVR, "xray", "x")
+	a.declare(client.WkGVR, "workload", "wk")
 }
 
 // Save alias to disk.
@@ -202,10 +199,10 @@ func (a *Aliases) SaveAliases(path string) error {
 	if err := data.EnsureDirPath(path, data.DefaultDirMod); err != nil {
 		return err
 	}
-	cfg, err := yaml.Marshal(a)
-	if err != nil {
-		return err
+	aa := newAliases(len(a.Alias))
+	for alias, gvr := range a.Alias {
+		aa.Alias[alias] = gvr.String()
 	}
 
-	return os.WriteFile(path, cfg, data.DefaultFileMod)
+	return data.SaveYAML(path, aa)
 }
