@@ -17,7 +17,7 @@ func TestClusterValidate(t *testing.T) {
 
 	assert.Equal(t, "po", c.View.Active)
 	assert.Equal(t, "default", c.Namespace.Active)
-	assert.Equal(t, 1, len(c.Namespace.Favorites))
+	assert.Len(t, c.Namespace.Favorites, 1)
 	assert.Equal(t, []string{"default"}, c.Namespace.Favorites)
 }
 
@@ -27,6 +27,6 @@ func TestClusterValidateEmpty(t *testing.T) {
 
 	assert.Equal(t, "po", c.View.Active)
 	assert.Equal(t, "default", c.Namespace.Active)
-	assert.Equal(t, 1, len(c.Namespace.Favorites))
+	assert.Len(t, c.Namespace.Favorites, 1)
 	assert.Equal(t, []string{"default"}, c.Namespace.Favorites)
 }
