@@ -9,6 +9,7 @@ import (
 	"testing"
 
 	"github.com/derailed/k9s/internal/model"
+	"github.com/derailed/k9s/internal/view/cmd"
 	"github.com/derailed/tcell/v2"
 	"github.com/derailed/tview"
 	"github.com/stretchr/testify/assert"
@@ -75,7 +76,7 @@ func TestStackPrevious(t *testing.T) {
 			for _, c := range u.items {
 				s.Push(c)
 			}
-			for i := 0; i < u.pops; i++ {
+			for range u.pops {
 				s.Pop()
 			}
 			assert.Equal(t, u.e, s.Previous())
@@ -110,7 +111,7 @@ func TestStackIsLast(t *testing.T) {
 			for _, c := range u.items {
 				s.Push(c)
 			}
-			for i := 0; i < u.pops; i++ {
+			for range u.pops {
 				s.Pop()
 			}
 			assert.Equal(t, u.e, s.IsLast())
@@ -141,7 +142,7 @@ func TestStackFlatten(t *testing.T) {
 				s.Push(c)
 			}
 			assert.Equal(t, u.e, s.Flatten())
-			assert.Equal(t, len(u.e), len(s.Peek()))
+			assert.Len(t, s.Peek(), len(u.e))
 		})
 	}
 }
@@ -179,7 +180,7 @@ func TestStackPush(t *testing.T) {
 			for _, c := range u.items {
 				s.Push(c)
 			}
-			for i := 0; i < u.pop; i++ {
+			for range u.pop {
 				s.Pop()
 			}
 			assert.Equal(t, u.e, s.Empty())
@@ -278,9 +279,10 @@ func (s *stackL) StackPushed(model.Component) {
 	s.count++
 }
 
-func (s *stackL) StackPopped(c, top model.Component) {
+func (s *stackL) StackPopped(_, _ model.Component) {
 	s.count--
 }
+
 func (s *stackL) StackTop(model.Component) { s.tops++ }
 
 type c struct {
@@ -291,23 +293,24 @@ func makeC(n string) c {
 	return c{name: n}
 }
 
-func (c) InCmdMode() bool                                              { return false }
-func (c c) Name() string                                               { return c.name }
-func (c c) Hints() model.MenuHints                                     { return nil }
-func (c c) HasFocus() bool                                             { return false }
-func (c c) ExtraHints() map[string]string                              { return nil }
-func (c c) Draw(tcell.Screen)                                          {}
-func (c c) InputHandler() func(*tcell.EventKey, func(tview.Primitive)) { return nil }
-func (c c) MouseHandler() func(action tview.MouseAction, event *tcell.EventMouse, setFocus func(p tview.Primitive)) (consumed bool, capture tview.Primitive) {
+func (c) InCmdMode() bool                                            { return false }
+func (c c) Name() string                                             { return c.name }
+func (c) SetCommand(*cmd.Interpreter)                                {}
+func (c) Hints() model.MenuHints                                     { return nil }
+func (c) HasFocus() bool                                             { return false }
+func (c) ExtraHints() map[string]string                              { return nil }
+func (c) Draw(tcell.Screen)                                          {}
+func (c) InputHandler() func(*tcell.EventKey, func(tview.Primitive)) { return nil }
+func (c) MouseHandler() func(action tview.MouseAction, event *tcell.EventMouse, setFocus func(p tview.Primitive)) (consumed bool, capture tview.Primitive) {
 	return nil
 }
-func (c c) SetRect(int, int, int, int)       {}
-func (c c) GetRect() (int, int, int, int)    { return 0, 0, 0, 0 }
-func (c c) GetFocusable() tview.Focusable    { return nil }
-func (c c) Focus(func(tview.Primitive))      {}
-func (c c) Blur()                            {}
-func (c c) Start()                           {}
-func (c c) Stop()                            {}
-func (c c) Init(context.Context) error       { return nil }
-func (c c) SetFilter(string)                 {}
-func (c c) SetLabelFilter(map[string]string) {}
+func (c) SetRect(int, int, int, int)       {}
+func (c) GetRect() (a, b, c, d int)        { return 0, 0, 0, 0 }
+func (c) GetFocusable() tview.Focusable    { return nil }
+func (c) Focus(func(tview.Primitive))      {}
+func (c) Blur()                            {}
+func (c) Start()                           {}
+func (c) Stop()                            {}
+func (c) Init(context.Context) error       { return nil }
+func (c) SetFilter(string)                 {}
+func (c) SetLabelFilter(map[string]string) {}
