@@ -1,3 +1,6 @@
+// SPDX-License-Identifier: Apache-2.0
+// Copyright Authors of K9s
+
 package tchart_test
 
 import (
@@ -10,7 +13,7 @@ import (
 
 func TestDial3x3(t *testing.T) {
 	d := tchart.NewDotMatrix()
-	for n := 0; n <= 2; n++ {
+	for n := range 2 {
 		i := n
 		t.Run(strconv.Itoa(n), func(t *testing.T) {
 			assert.Equal(t, tchart.To3x3Char(i), d.Print(i))
