@@ -37,7 +37,7 @@ type (
 // Table represents tabular data.
 type Table struct {
 	*SelectTable
-	gvr         client.GVR
+	gvr         *client.GVR
 	sortCol     model1.SortColumn
 	manualSort  bool
 	Path        string
@@ -59,7 +59,7 @@ type Table struct {
 }
 
 // NewTable returns a new table view.
-func NewTable(gvr client.GVR) *Table {
+func NewTable(gvr *client.GVR) *Table {
 	return &Table{
 		SelectTable: &SelectTable{
 			Table: tview.NewTable(),
@@ -140,6 +140,7 @@ func (t *Table) SetViewSetting(vs *config.ViewSetting) bool {
 
 	if !t.viewSetting.Equals(vs) {
 		t.viewSetting = vs
+		slog.Debug("Updating custom view setting", slogs.GVR, t.gvr, slogs.ViewSetting, vs)
 		t.model.SetViewSetting(t.ctx, vs)
 		return true
 	}
@@ -178,7 +179,7 @@ func (t *Table) Init(ctx context.Context) {
 }
 
 // GVR returns a resource descriptor.
-func (t *Table) GVR() client.GVR { return t.gvr }
+func (t *Table) GVR() *client.GVR { return t.gvr }
 
 // ViewSettingsChanged notifies listener the view configuration changed.
 func (t *Table) ViewSettingsChanged(vs *config.ViewSetting) {
@@ -250,7 +251,7 @@ func (t *Table) FilterInput(r rune) bool {
 }
 
 // Filter filters out table data.
-func (t *Table) Filter(q string) {
+func (t *Table) Filter(string) {
 	t.ClearSelection()
 	t.doUpdate(t.filtered(t.GetModel().Peek()))
 	t.UpdateTitle()
@@ -263,7 +264,7 @@ func (t *Table) Hints() model.MenuHints {
 }
 
 // ExtraHints returns additional hints.
-func (t *Table) ExtraHints() map[string]string {
+func (*Table) ExtraHints() map[string]string {
 	return nil
 }
 
@@ -433,7 +434,7 @@ func (t *Table) buildRow(r int, re, ore model1.RowEvent, h model1.Header, pads M
 
 // SortColCmd designates a sorted column.
 func (t *Table) SortColCmd(name string, asc bool) func(evt *tcell.EventKey) *tcell.EventKey {
-	return func(evt *tcell.EventKey) *tcell.EventKey {
+	return func(*tcell.EventKey) *tcell.EventKey {
 		sc := t.getSortCol()
 		sc.ASC = !sc.ASC
 		if sc.Name != name {
@@ -448,7 +449,7 @@ func (t *Table) SortColCmd(name string, asc bool) func(evt *tcell.EventKey) *tce
 }
 
 // SortInvertCmd reverses sorting order.
-func (t *Table) SortInvertCmd(evt *tcell.EventKey) *tcell.EventKey {
+func (t *Table) SortInvertCmd(*tcell.EventKey) *tcell.EventKey {
 	t.toggleSortCol()
 	t.Refresh()
 
@@ -500,7 +501,8 @@ func (t *Table) NameColIndex() int {
 func (t *Table) AddHeaderCell(col int, h model1.HeaderColumn) {
 	sc := t.getSortCol()
 	sortCol := h.Name == sc.Name
-	c := tview.NewTableCell(sortIndicator(sortCol, sc.ASC, t.styles.Table(), h.Name))
+	styles := t.styles.Table()
+	c := tview.NewTableCell(sortIndicator(sortCol, sc.ASC, &styles, h.Name))
 	c.SetExpansion(1)
 	c.SetSelectable(false)
 	c.SetAlign(h.Align)
@@ -523,7 +525,7 @@ func (t *Table) CmdBuff() *model.FishBuff {
 func (t *Table) ShowDeleted() {
 	r, _ := t.GetSelection()
 	cols := t.GetColumnCount()
-	for x := 0; x < cols; x++ {
+	for x := range cols {
 		t.GetCell(r, x).SetAttributes(tcell.AttrDim)
 	}
 }
@@ -561,14 +563,14 @@ func (t *Table) styleTitle() string {
 		resource = t.gvr.String()
 	}
 
-	var title string
+	var (
+		title  string
+		styles = t.styles.Frame()
+	)
 	if ns == client.ClusterScope {
-		title = SkinTitle(fmt.Sprintf(TitleFmt, resource, render.AsThousands(rc)), t.styles.Frame())
+		title = SkinTitle(fmt.Sprintf(TitleFmt, resource, render.AsThousands(rc)), &styles)
 	} else {
-		title = SkinTitle(fmt.Sprintf(NSTitleFmt, resource, ns, render.AsThousands(rc)), t.styles.Frame())
-	}
-	if ic := ROIndicator(t.readOnly, t.noIcon); ic != "" {
-		title = " " + ic + title
+		title = SkinTitle(fmt.Sprintf(NSTitleFmt, resource, ns, render.AsThousands(rc)), &styles)
 	}
 
 	buff := t.cmdBuff.GetText()
@@ -582,7 +584,7 @@ func (t *Table) styleTitle() string {
 		return title
 	}
 
-	return title + SkinTitle(fmt.Sprintf(SearchFmt, buff), t.styles.Frame())
+	return title + SkinTitle(fmt.Sprintf(SearchFmt, buff), &styles)
 }
 
 // ROIndicator returns an icon showing whether the session is in readonly mode or not.
