@@ -14,6 +14,7 @@ import (
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/derailed/k9s/internal/ui/dialog"
 	"github.com/derailed/tcell/v2"
+	"k8s.io/apimachinery/pkg/util/sets"
 )
 
 // AllScopes represents actions available for all views.
@@ -21,9 +22,16 @@ const AllScopes = "all"
 
 // Runner represents a runnable action handler.
 type Runner interface {
+	// App returns the current app.
 	App() *App
+
+	// GetSelectedItem returns the current selected item.
 	GetSelectedItem() string
-	Aliases() map[string]struct{}
+
+	// Aliases returns all aliases assoxciated with the view GVR.
+	Aliases() sets.Set[string]
+
+	// EnvFn returns the current environment function.
 	EnvFn() EnvFunc
 }
 
@@ -45,7 +53,7 @@ func includes(aliases []string, s string) bool {
 	return false
 }
 
-func inScope(scopes []string, aliases map[string]struct{}) bool {
+func inScope(scopes []string, aliases sets.Set[string]) bool {
 	if hasAll(scopes) {
 		return true
 	}
@@ -81,8 +89,8 @@ func hotKeyActions(r Runner, aa *ui.KeyActions) error {
 				errs = errors.Join(errs, fmt.Errorf("duplicate hotkey found for %q in %q", hk.ShortCut, k))
 				continue
 			}
-			slog.Debug("Action has been overridden by hotkey",
-				slogs.Action, hk.ShortCut,
+			slog.Debug("HotKey overrode action shortcut",
+				slogs.Shortcut, hk.ShortCut,
 				slogs.Key, k,
 			)
 		}
@@ -107,7 +115,7 @@ func hotKeyActions(r Runner, aa *ui.KeyActions) error {
 }
 
 func gotoCmd(r Runner, cmd, path string, clearStack bool) ui.ActionHandler {
-	return func(evt *tcell.EventKey) *tcell.EventKey {
+	return func(*tcell.EventKey) *tcell.EventKey {
 		r.App().gotoResource(cmd, path, clearStack, true)
 		return nil
 	}
@@ -125,7 +133,7 @@ func pluginActions(r Runner, aa *ui.KeyActions) error {
 		return err
 	}
 	pp := config.NewPlugins()
-	if err := pp.Load(path); err != nil {
+	if err := pp.Load(path, true); err != nil {
 		return err
 	}
 
@@ -134,32 +142,30 @@ func pluginActions(r Runner, aa *ui.KeyActions) error {
 		aliases = r.Aliases()
 		ro      = r.App().Config.IsReadOnly()
 	)
-	for k, plugin := range pp.Plugins {
-		if !inScope(plugin.Scopes, aliases) {
+	for k := range pp.Plugins {
+		if !inScope(pp.Plugins[k].Scopes, aliases) || (ro && pp.Plugins[k].Dangerous) {
 			continue
 		}
-		key, err := asKey(plugin.ShortCut)
+		key, err := asKey(pp.Plugins[k].ShortCut)
 		if err != nil {
 			errs = errors.Join(errs, err)
 			continue
 		}
 		if _, ok := aa.Get(key); ok {
-			if !plugin.Override {
-				errs = errors.Join(errs, fmt.Errorf("duplicate plugin key found for %q in %q", plugin.ShortCut, k))
+			if !pp.Plugins[k].Override {
+				errs = errors.Join(errs, fmt.Errorf("duplicate plugin key found for %q in %q", pp.Plugins[k].ShortCut, k))
 				continue
 			}
-			slog.Debug("Action has been overridden by plugin action",
-				slogs.Action, plugin.ShortCut,
-				slogs.Key, k,
+			slog.Debug("Plugin overrode action shortcut",
+				slogs.Plugin, k,
+				slogs.Key, pp.Plugins[k].ShortCut,
 			)
 		}
 
-		if plugin.Dangerous && ro {
-			continue
-		}
+		plugin := pp.Plugins[k]
 		aa.Add(key, ui.NewKeyActionWithOpts(
-			plugin.Description,
-			pluginAction(r, plugin),
+			pp.Plugins[k].Description,
+			pluginAction(r, &plugin),
 			ui.ActionOpts{
 				Visible:   true,
 				Plugin:    true,
@@ -171,7 +177,7 @@ func pluginActions(r Runner, aa *ui.KeyActions) error {
 	return errs
 }
 
-func pluginAction(r Runner, p config.Plugin) ui.ActionHandler {
+func pluginAction(r Runner, p *config.Plugin) ui.ActionHandler {
 	return func(evt *tcell.EventKey) *tcell.EventKey {
 		path := r.GetSelectedItem()
 		if path == "" {
@@ -198,7 +204,7 @@ func pluginAction(r Runner, p config.Plugin) ui.ActionHandler {
 				pipes:      p.Pipes,
 				args:       args,
 			}
-			suspend, errChan, statusChan := run(r.App(), opts)
+			suspend, errChan, statusChan := run(r.App(), &opts)
 			if !suspend {
 				r.App().Flash().Infof("Plugin command failed: %q", p.Description)
 				return
@@ -222,11 +228,11 @@ func pluginAction(r Runner, p config.Plugin) ui.ActionHandler {
 					}
 				}
 			}()
-
 		}
 		if p.Confirm {
 			msg := fmt.Sprintf("Run?\n%s %s", p.Command, strings.Join(args, " "))
-			dialog.ShowConfirm(r.App().Styles.Dialog(), r.App().Content.Pages, "Confirm "+p.Description, msg, cb, func() {})
+			d := r.App().Styles.Dialog()
+			dialog.ShowConfirm(&d, r.App().Content.Pages, "Confirm "+p.Description, msg, cb, func() {})
 			return nil
 		}
 		cb()
