@@ -17,6 +17,12 @@ import (
 	"github.com/derailed/k9s/internal/model"
 	"github.com/derailed/k9s/internal/slogs"
 	"github.com/derailed/k9s/internal/view/cmd"
+	"k8s.io/apimachinery/pkg/util/sets"
+)
+
+const (
+	podCmd = "pod"
+	ctxCmd = "ctx"
 )
 
 var (
@@ -39,8 +45,8 @@ func NewCommand(app *App) *Command {
 }
 
 // AliasesFor gather all known aliases for a given resource.
-func (c *Command) AliasesFor(s string) []string {
-	return c.alias.AliasesFor(s)
+func (c *Command) AliasesFor(gvr *client.GVR) sets.Set[string] {
+	return c.alias.AliasesFor(gvr)
 }
 
 // Init initializes the command.
@@ -56,11 +62,11 @@ func (c *Command) Init(path string) error {
 }
 
 // Reset resets Command and reload aliases.
-func (c *Command) Reset(path string, clear bool) error {
+func (c *Command) Reset(path string, nuke bool) error {
 	c.mx.Lock()
 	defer c.mx.Unlock()
 
-	if clear {
+	if nuke {
 		c.alias.Clear()
 	}
 	if _, err := c.alias.Ensure(path); err != nil {
@@ -70,18 +76,17 @@ func (c *Command) Reset(path string, clear bool) error {
 	return nil
 }
 
-func allowedXRay(gvr client.GVR) bool {
-	gg := map[string]struct{}{
-		"v1/pods":              {},
-		"v1/services":          {},
-		"apps/v1/deployments":  {},
-		"apps/v1/daemonsets":   {},
-		"apps/v1/statefulsets": {},
-		"apps/v1/replicasets":  {},
-	}
-	_, ok := gg[gvr.String()]
+var allowedCmds = sets.New[*client.GVR](
+	client.PodGVR,
+	client.SvcGVR,
+	client.DpGVR,
+	client.DsGVR,
+	client.StsGVR,
+	client.RsGVR,
+)
 
-	return ok
+func allowedXRay(gvr *client.GVR) bool {
+	return allowedCmds.Has(gvr)
 }
 
 func (c *Command) contextCmd(p *cmd.Interpreter, pushCmd bool) error {
@@ -102,7 +107,7 @@ func (c *Command) contextCmd(p *cmd.Interpreter, pushCmd bool) error {
 	return c.exec(p, gvr, c.componentFor(gvr, ct, v), true, pushCmd)
 }
 
-func (c *Command) namespaceCmd(p *cmd.Interpreter) bool {
+func (*Command) namespaceCmd(p *cmd.Interpreter) bool {
 	ns, ok := p.NSArg()
 	if !ok {
 		return false
@@ -118,11 +123,10 @@ func (c *Command) namespaceCmd(p *cmd.Interpreter) bool {
 func (c *Command) aliasCmd(p *cmd.Interpreter, pushCmd bool) error {
 	filter, _ := p.FilterArg()
 
-	gvr := client.NewGVR("aliases")
-	v := NewAlias(gvr)
+	v := NewAlias(client.AliGVR)
 	v.SetFilter(filter)
 
-	return c.exec(p, gvr, v, false, pushCmd)
+	return c.exec(p, client.AliGVR, v, false, pushCmd)
 }
 
 func (c *Command) xrayCmd(p *cmd.Interpreter, pushCmd bool) error {
@@ -152,7 +156,7 @@ func (c *Command) xrayCmd(p *cmd.Interpreter, pushCmd bool) error {
 }
 
 // Run execs the command by showing associated display.
-func (c *Command) run(p *cmd.Interpreter, fqn string, clearStack bool, pushCmd bool) error {
+func (c *Command) run(p *cmd.Interpreter, fqn string, clearStack, pushCmd bool) error {
 	if c.specialCmd(p, pushCmd) {
 		return nil
 	}
@@ -169,7 +173,7 @@ func (c *Command) run(p *cmd.Interpreter, fqn string, clearStack bool, pushCmd b
 				slog.Debug("Successfully saved config", slogs.Context, context)
 			}
 		}
-		res, err := dao.AccessorFor(c.app.factory, client.NewGVR("contexts"))
+		res, err := dao.AccessorFor(c.app.factory, client.CtGVR)
 		if err != nil {
 			return err
 		}
@@ -215,9 +219,9 @@ func (c *Command) defaultCmd(isRoot bool) error {
 		return c.run(cmd.NewInterpreter("context"), "", true, true)
 	}
 
-	defCmd := "pod"
+	defCmd := podCmd
 	if isRoot {
-		defCmd = "ctx"
+		defCmd = ctxCmd
 	}
 	p := cmd.NewInterpreter(c.app.Config.ActiveView())
 	if p.IsBlank() {
@@ -281,22 +285,21 @@ func (c *Command) specialCmd(p *cmd.Interpreter, pushCmd bool) bool {
 	return true
 }
 
-func (c *Command) viewMetaFor(p *cmd.Interpreter) (client.GVR, *MetaViewer, error) {
-	agvr, exp, ok := c.alias.AsGVR(p.Cmd())
+func (c *Command) viewMetaFor(p *cmd.Interpreter) (*client.GVR, *MetaViewer, error) {
+	gvr, exp, ok := c.alias.AsGVR(p.Cmd())
 	if !ok {
 		return client.NoGVR, nil, fmt.Errorf("`%s` command not found", p.Cmd())
 	}
-	gvr := agvr
 	if exp != "" {
 		ff := strings.Fields(exp)
-		ff[0] = agvr.String()
+		ff[0] = gvr.String()
 		ap := cmd.NewInterpreter(strings.Join(ff, " "))
 		gvr = client.NewGVR(ap.Cmd())
 		p.Amend(ap)
 	}
 
 	v := MetaViewer{
-		viewerFn: func(gvr client.GVR) ResourceViewer {
+		viewerFn: func(gvr *client.GVR) ResourceViewer {
 			return NewScaleExtender(NewOwnerExtender(NewBrowser(gvr)))
 		},
 	}
@@ -307,7 +310,7 @@ func (c *Command) viewMetaFor(p *cmd.Interpreter) (client.GVR, *MetaViewer, erro
 	return gvr, &v, nil
 }
 
-func (c *Command) componentFor(gvr client.GVR, fqn string, v *MetaViewer) ResourceViewer {
+func (*Command) componentFor(gvr *client.GVR, fqn string, v *MetaViewer) ResourceViewer {
 	var view ResourceViewer
 	if v.viewerFn != nil {
 		view = v.viewerFn(gvr)
@@ -323,27 +326,29 @@ func (c *Command) componentFor(gvr client.GVR, fqn string, v *MetaViewer) Resour
 	return view
 }
 
-func (c *Command) exec(p *cmd.Interpreter, gvr client.GVR, comp model.Component, clearStack bool, pushCmd bool) (err error) {
+func (c *Command) exec(p *cmd.Interpreter, gvr *client.GVR, comp model.Component, clearStack, pushCmd bool) (err error) {
 	defer func() {
 		if e := recover(); e != nil {
 			slog.Error("Failure detected during command exec", slogs.Error, e)
 			c.app.Content.Dump()
 			slog.Debug("Dumping history buffer", slogs.CmdHist, c.app.cmdHistory.List())
-			slog.Error("Dumping stack", slogs.Stack, debug.Stack())
+			slog.Error("Dumping stack", slogs.Stack, string(debug.Stack()))
 
-			p := cmd.NewInterpreter("pod")
+			ci := cmd.NewInterpreter(podCmd)
 			cmds := c.app.cmdHistory.List()
 			currentCommand := cmds[c.app.cmdHistory.CurrentIndex()]
-			if currentCommand != "pod" {
-				p = p.Reset(currentCommand)
+			if currentCommand != podCmd {
+				ci = ci.Reset(currentCommand)
 			}
-			err = c.run(p, "", true, true)
+			err = c.run(ci, "", true, true)
 		}
 	}()
 
 	if comp == nil {
 		return fmt.Errorf("no component found for %s", gvr)
 	}
+	comp.SetCommand(p)
+
 	c.app.Flash().Infof("Viewing %s...", gvr)
 	if clearStack {
 		cmd := contextRX.ReplaceAllString(p.GetLine(), "")
@@ -352,10 +357,10 @@ func (c *Command) exec(p *cmd.Interpreter, gvr client.GVR, comp model.Component,
 	if err := c.app.inject(comp, clearStack); err != nil {
 		return err
 	}
-
 	if pushCmd {
 		c.app.cmdHistory.Push(p.GetLine())
 	}
+	slog.Debug("History", slogs.Stack, c.app.cmdHistory.List())
 
 	return
 }
