@@ -9,12 +9,13 @@ import (
 	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/view"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestDeploy(t *testing.T) {
-	v := view.NewDeploy(client.NewGVR("apps/v1/deployments"))
+	v := view.NewDeploy(client.DpGVR)
 
-	assert.Nil(t, v.Init(makeCtx()))
+	require.NoError(t, v.Init(makeCtx()))
 	assert.Equal(t, "Deployments", v.Name())
-	assert.Equal(t, 16, len(v.Hints()))
+	assert.Len(t, v.Hints(), 16)
 }
