@@ -11,19 +11,20 @@ import (
 	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/view"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestHelp(t *testing.T) {
 	ctx := makeCtx()
 
 	app := ctx.Value(internal.KeyApp).(*view.App)
-	po := view.NewPod(client.NewGVR("v1/pods"))
-	assert.NoError(t, po.Init(ctx))
+	po := view.NewPod(client.PodGVR)
+	require.NoError(t, po.Init(ctx))
 	app.Content.Push(po)
 
 	v := view.NewHelp(app)
 
-	assert.Nil(t, v.Init(ctx))
+	require.NoError(t, v.Init(ctx))
 	assert.Equal(t, 29, v.GetRowCount())
 	assert.Equal(t, 8, v.GetColumnCount())
 	assert.Equal(t, "<a>", strings.TrimSpace(v.GetCell(1, 0).Text))
