@@ -21,7 +21,7 @@ type Namespace struct {
 }
 
 // NewNamespace returns a new viewer.
-func NewNamespace(gvr client.GVR) ResourceViewer {
+func NewNamespace(gvr *client.GVR) ResourceViewer {
 	n := Namespace{
 		ResourceViewer: NewBrowser(gvr),
 	}
@@ -39,12 +39,12 @@ func (n *Namespace) bindKeys(aa *ui.KeyActions) {
 	})
 }
 
-func (n *Namespace) switchNs(app *App, _ ui.Tabular, _ client.GVR, path string) {
+func (n *Namespace) switchNs(app *App, _ ui.Tabular, _ *client.GVR, path string) {
 	n.useNamespace(path)
-	app.gotoResource("pods", "", false)
+	app.gotoResource("pods", "", false, true)
 }
 
-func (n *Namespace) useNsCmd(evt *tcell.EventKey) *tcell.EventKey {
+func (n *Namespace) useNsCmd(*tcell.EventKey) *tcell.EventKey {
 	path := n.GetTable().GetSelectedItem()
 	if path == "" {
 		return nil
