@@ -9,12 +9,13 @@ import (
 	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/view"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestPortForwardNew(t *testing.T) {
-	pf := view.NewPortForward(client.NewGVR("portforwards"))
+	pf := view.NewPortForward(client.PfGVR)
 
-	assert.Nil(t, pf.Init(makeCtx()))
+	require.NoError(t, pf.Init(makeCtx()))
 	assert.Equal(t, "PortForwards", pf.Name())
-	assert.Equal(t, 10, len(pf.Hints()))
+	assert.Len(t, pf.Hints(), 10)
 }
