@@ -12,14 +12,15 @@ import (
 	"github.com/derailed/k9s/internal/config/mock"
 	"github.com/derailed/k9s/internal/view"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestPodNew(t *testing.T) {
-	po := view.NewPod(client.NewGVR("v1/pods"))
+	po := view.NewPod(client.PodGVR)
 
-	assert.Nil(t, po.Init(makeCtx()))
+	require.NoError(t, po.Init(makeCtx()))
 	assert.Equal(t, "Pods", po.Name())
-	assert.Equal(t, 28, len(po.Hints()))
+	assert.Len(t, po.Hints(), 28)
 }
 
 // Helpers...
